local f = CreateFrame("Frame")
local sounds = {
	"Interface\\AddOns\\Awwwww!\\sounds\\DonkeyKong-Die.ogg",			--Donkey Kong
	"Interface\\AddOns\\Awwwww!\\sounds\\SuperMario-Die.ogg",			--Mario
	"Interface\\AddOns\\Awwwww!\\sounds\\Mega Man Dies_3.ogg",			--Mega Man
	"Interface\\AddOns\\Awwwww!\\sounds\\MsPacMan-Death.ogg",			--Ms. PacMan
	"Interface\\AddOns\\Awwwww!\\sounds\\PacMan-Killed.ogg",			--PacMan
	"Interface\\AddOns\\Awwwww!\\sounds\\PriceIsRight-GameOver.ogg",	--The Price Is Right
	"Interface\\AddOns\\Awwwww!\\sounds\\LegendOfZelda-Die.ogg",		--Zelda
}
local values = {
	"Random",
	"Donkey Kong",
	"Mario",
	"Mega Man",
	"Ms. PacMan",
	"PacMan",
	"The Price Is Right",
	"Zelda",
}
local channels = {
	"Master",
	"SFX",
	"Ambience",
	"Music",
}

local defaults = {
	sound = 1,
	channel = 1,
}

--local rand
local function DeathSound()
	if AwwwwwDB.sound == 1 then	--if set to "Random"
		PlaySoundFile(sounds[math.random(#sounds)], channels[AwwwwwDB.channel])
	else
		PlaySoundFile(sounds[AwwwwwDB.sound -1], channels[AwwwwwDB.channel])	-- -1 because "Random" is 1
	end
end

local function AddOptions()
	local OnEnter = function(self, title, text)
		GameTooltip:SetOwner(self, "ANCHOR_TOPRIGHT")
		GameTooltip:SetText(title)
		GameTooltip:AddLine(text,1,1,1,true)
		GameTooltip:Show()
	end

	local header = f:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
		header:SetParent(f)
		header:SetPoint("TOPLEFT", f, "TOPLEFT", 20,-15)
		header:SetText("Awwwww!")

	local subheader = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
		subheader:SetParent(f)
		subheader:SetPoint("TOPLEFT", header, "BOTTOMLEFT", 0,-10)
		subheader:SetPoint("RIGHT", f, "RIGHT", -20,0)
		subheader:SetHeight(30)
		subheader:SetNonSpaceWrap(true)
		subheader:SetJustifyH("LEFT")
		subheader:SetText("This addon will play one or all of the following sounds upon your death.")

	local dropdown = CreateFrame("Frame", "Awwwww_Dropdown", f, "UIDropDownMenuTemplate")
		local dropbutton = Awwwww_DropdownButton
		local dropTable = {}
		for k,v in pairs(values) do
			dropTable[k] = {
				text = v,
				checked = function() return AwwwwwDB.sound == k end,
				func = function()
						AwwwwwDB.sound = k
						UIDropDownMenu_SetText(dropdown, v)
					end,
			}
		end
		UIDropDownMenu_SetText(dropdown, values[AwwwwwDB.sound])
		UIDropDownMenu_SetWidth(dropdown, 175)
		dropdown:SetPoint("TOPLEFT", subheader, "BOTTOMLEFT", -15,-55)
		dropdown.point = "TOPRIGHT"
		dropdown.relativePoint = "BOTTOMRIGHT"
		dropbutton:SetScript("OnClick", function(self, button, down)
				EasyMenu(dropTable, dropdown, self:GetName(), 0, 5, nil, 5)
			end)
		dropbutton:SetScript("OnEnter", function(self) OnEnter(self,"Usage","Select which sound to play upon your death.  Select 'Random' if you wish to hear all of them.") end)
		dropbutton:SetScript("OnLeave", function() GameTooltip:Hide() end)
	local dropTitle = dropdown:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		dropTitle:SetParent(f)
		dropTitle:SetPoint("BOTTOMLEFT", dropdown, "TOPLEFT", 20,5)
		dropTitle:SetText("Usage")

	local button = CreateFrame("Button", nil, f)
		button:SetWidth(140)
		button:SetHeight(25)
		button:SetPoint("LEFT", dropdown, "RIGHT", 20,3)
		button:SetNormalTexture("Interface\\Buttons\\UI-Panel-Button-Up.blp")
		button:GetNormalTexture():SetTexCoord(0,.64,0,.64)
		button:SetHighlightTexture("Interface\\Buttons\\UI-Panel-Button-Highlight.blp")
		button:GetHighlightTexture():SetTexCoord(0,.64,0,.64)
		button:SetPushedTexture("Interface\\Buttons\\UI-Panel-Button-Down.blp")
		button:GetPushedTexture():SetTexCoord(0,.64,0,.64)
		button:SetNormalFontObject("GameFontHighlight")
		button:SetText("Test")
		button:SetScript("OnEnter", function(self) OnEnter(self,"Test","Hear the sound you've selected.") end)
		button:SetScript("OnLeave", function() GameTooltip:Hide() end)
		button:SetScript("OnClick", DeathSound)

	local dropdown2 = CreateFrame("Frame", "Awwwww_Dropdown2", f, "UIDropDownMenuTemplate")
		local dropbutton2 = Awwwww_Dropdown2Button
		local dropTable2 = {}
		for k,v in pairs(channels) do
			dropTable2[k] = {
				text = v,
				checked = function() return AwwwwwDB.channel == k end,
				func = function()
						AwwwwwDB.channel = k
						UIDropDownMenu_SetText(dropdown2, v)
					end,
			}
		end
		UIDropDownMenu_SetText(dropdown2, channels[AwwwwwDB.channel])
		UIDropDownMenu_SetWidth(dropdown2, 175)
		dropdown2:SetPoint("TOPLEFT", dropdown, "BOTTOMLEFT", 0,-55)
		dropdown2.point = "TOPRIGHT"
		dropdown2.relativePoint = "BOTTOMRIGHT"
		dropbutton2:SetScript("OnClick", function(self, button, down)
				EasyMenu(dropTable2, dropdown2, self:GetName(), 0, 5, nil, 5)
			end)
		dropbutton2:SetScript("OnEnter", function(self) OnEnter(self,"Sound Channel","Select which channel the sound should be played on.  The volume of individual channels and the Master game volume may be adjusted by going to: Escape > Options > Sound.") end)
		dropbutton2:SetScript("OnLeave", function() GameTooltip:Hide() end)
	local dropTitle2 = dropdown2:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		dropTitle2:SetParent(f)
		dropTitle2:SetPoint("BOTTOMLEFT", dropdown2, "TOPLEFT", 20,5)
		dropTitle2:SetText("Sound Channel")
end

local function OnInitialize()
	AwwwwwDB = AwwwwwDB or {}
	for k,v in pairs(defaults) do
	    if type(AwwwwwDB[k]) == "nil" then
	        AwwwwwDB[k] = v
	    end
	end
	
	f.name = "Awwwww!"
	InterfaceOptions_AddCategory(f)
	AddOptions()
	
	f:UnregisterEvent("PLAYER_LOGIN")
	f:RegisterEvent("PLAYER_DEAD")
	f:SetScript("OnEvent", DeathSound)
	
	AddOptions = nil
	OnInitialize = nil
end


f:SetScript("OnEvent", OnInitialize)
f:RegisterEvent("PLAYER_LOGIN")